Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4573)

Unified Diff: chrome/browser/ui/views/frame/minimize_button_metrics_win.h

Issue 2851543002: Update avatar button to MD (part 1) (Closed)
Patch Set: Rebased on CL 2868293002 [Rename new_avatar_button.* to avatar_button] Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/minimize_button_metrics_win.h
diff --git a/chrome/browser/ui/views/frame/minimize_button_metrics_win.h b/chrome/browser/ui/views/frame/minimize_button_metrics_win.h
index 86d08a4b5f9da28c860b3db691d96cb67eabb6a9..3319dc14340ef2bb48b07f0369d284c363ac3090 100644
--- a/chrome/browser/ui/views/frame/minimize_button_metrics_win.h
+++ b/chrome/browser/ui/views/frame/minimize_button_metrics_win.h
@@ -18,7 +18,8 @@ class MinimizeButtonMetrics {
MinimizeButtonMetrics();
~MinimizeButtonMetrics();
// Returns the height of the native caption buttons in DIPs.
Peter Kasting 2017/05/11 01:03:43 Nit: "Returns" was correct; see bit about "descrip
emx 2017/05/11 12:56:11 Oh, it was supposed to be plural to apply to both
+ static int GetCaptionButtonWidthInDIPs();
static int GetCaptionButtonHeightInDIPs();
Peter Kasting 2017/05/11 01:03:43 Nit: Maybe static gfx::Size GetCaptionButtonSiz
emx 2017/05/11 12:56:11 Good point, I'll use this if we ever figure out a
void Init(HWND hwnd);
@@ -33,6 +34,9 @@ class MinimizeButtonMetrics {
void OnHWNDActivated();
private:
+ static int GetCaptionButtonDimensionInDIPs(int caption_metric,
+ int frame_metric);
+
// Gets the value for GetMinimizeButtonOffsetX(), caching if found.
int GetAndCacheMinimizeButtonOffsetX() const;
@@ -18,7 +18,8 @@ class MinimizeButtonMetrics {
MinimizeButtonMetrics();
~MinimizeButtonMetrics();
- // Returns the height of the native caption buttons in DIPs.
+ // Return the width/height of the native caption buttons in DIPs.
Peter Kasting 2017/05/11 01:03:43 Nit: "Returns" was correct; see bit about "descrip
emx 2017/05/11 12:56:11 Oh, it was supposed to be plural to apply to both

Powered by Google App Engine
This is Rietveld 408576698